@@ -3,9 +3,7 @@
 module.exports = function (t, a) {
 	a(t([]), true, "Array");
 	a(t(""), true, "String");
-	a(t((function () {
- return arguments;
-}())), true, "Arguments");
+	a(t((function () { return arguments; })()), true, "Arguments");
 	a(t({ length: 0 }), true, "List object");
 	a(t(function () {}), false, "Function");
 	a(t({}), false, "Plain object");
