@@ -2,6 +2,4 @@
 
 var isImplemented = require("../../../../string/#/starts-with/is-implemented");
 
-module.exports = function (a) {
- a(isImplemented(), true);
-};
+module.exports = function (a) { a(isImplemented(), true); };
